@@ -2,7 +2,7 @@ package HTML::FormFu::Element::File;
 
 use strict;
 use base 'HTML::FormFu::Element::_Input';
-use Class::C3;
+use mro 'c3';
 
 sub new {
     my $self = shift->next::method(@_);
@@ -59,7 +59,7 @@ L<HTML::FormFu::Element::_Input>,
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -69,3 +69,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
