@@ -2,9 +2,11 @@ package HTML::FormFu::Element::Password;
 
 use strict;
 use base 'HTML::FormFu::Element::_Input';
-use Class::C3;
+use mro 'c3';
 
-__PACKAGE__->mk_accessors(qw/ render_value /);
+use HTML::FormFu::Constants qw( $EMPTY_STR );
+
+__PACKAGE__->mk_item_accessors(qw( render_value ));
 
 sub new {
     my $self = shift->next::method(@_);
@@ -21,14 +23,19 @@ sub process_value {
     my $new;
 
     if ( $submitted && $self->render_value ) {
-        $new = defined $value ? $value : "";
+        $new
+            = defined $value
+            ? $value
+            : $EMPTY_STR;
 
-        $new = $self->value if $self->retain_default && $new eq "";
+        if ( $self->retain_default && $new eq $EMPTY_STR ) {
+            $new = $self->value;
+        }
 
         $self->value($new);
     }
     elsif ($submitted) {
-        $new = "";
+        $new = $EMPTY_STR;
     }
     else {
         $new = undef;
@@ -55,6 +62,15 @@ Password form field.
 
 =head1 METHODS
 
+=head2 render_value
+
+Normally, when a form is redisplayed because of errors, password fields
+lose their values, requiring the user to retype it.
+
+If C<render_value> is true, password fields won't lose their value.
+
+Default value: false
+
 =head1 SEE ALSO
 
 Is a sub-class of, and inherits methods from 
@@ -62,7 +78,7 @@ L<HTML::FormFu::Element::_Input>,
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -72,3 +88,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
