@@ -1,7 +1,7 @@
 package HTML::FormFu::Processor;
 
 use strict;
-use Class::C3;
+use mro 'c3';
 
 use HTML::FormFu::Attribute qw(
     mk_item_accessors
@@ -13,9 +13,11 @@ use HTML::FormFu::ObjectUtil qw(
     populate                form
     name                    nested_name
     nested_names            get_nested_hash_value
-    set_nested_hash_value   nested_hash_key_exists parent );
+    set_nested_hash_value   nested_hash_key_exists
+    parent                  get_parent
+);
 
-use Scalar::Util qw( refaddr );
+use Scalar::Util qw( refaddr reftype );
 use Carp qw( croak );
 
 use overload
@@ -34,10 +36,14 @@ __PACKAGE__->mk_inherited_accessors(qw( locale ));
 
 sub new {
     my $class = shift;
-
     my %attrs;
-    eval { %attrs = %{ $_[0] } if @_ };
-    croak "attributes argument must be a hashref" if $@;
+    
+    if (@_) {
+        croak "attributes argument must be a hashref"
+            if reftype( $_[0] ) ne 'HASH';
+        
+        %attrs = %{ $_[0] };
+    }
 
     my $self = bless {}, $class;
 
@@ -106,3 +112,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
